%********************************************************************%
%                                                                    %
%  function A_to_thomsen                                             %
%                                                                    %
%  function calculates Thomsen's parameters from elastic parameters  %
%                                                                    %
%********************************************************************%
function Thomsen_parameters = a_to_thomsen(elastic_parameters)

a11  = elastic_parameters(1);
a33  = elastic_parameters(2);
a44  = elastic_parameters(3);
a66  = elastic_parameters(4);
a13  = elastic_parameters(5);

%--------------------------------------------------------------------
% calculation od Thomsen's parameters

alfa_thomsen = sqrt(a33);
beta_thomsen = sqrt(a44);

eps_thomsen    = (a11-a33)/(2*a33);
gamma_thomsen  = (a66-a44)/(2*a44);
delta_thomsen  = 1/(2*a33)*(((a13+a44)^2-(a33-a44)^2)/(a33-a44));
sigma_thomsen  = a33/a44*(eps_thomsen-delta_thomsen);
%sigma_thomsen  = 1/(2*a44)*(a11-a44-(a13+a44)^2/(a33-a44));

Thomsen_parameters = [alfa_thomsen beta_thomsen eps_thomsen delta_thomsen gamma_thomsen sigma_thomsen];





