%********************************************************************%
%                                                                    %
%  PROGRAM thomsen_parameters.m                                      %
%                                                                    %
%  program calculates elastic parameters from Thomsen's parameters   %
%  and vice versa                                                    %
%                                                                    %
%********************************************************************%

%--------------------------------------------------------------------
% calculation of elastic parameters from Thomsen's parameters
%--------------------------------------------------------------------
% Model - mesaverde (5481) immature sandstone                       
%        (Thomsen 1986, Geophysics 51, 1954-1966)                   
%--------------------------------------------------------------------

alfa_thomsen  = 4.349;
beta_thomsen  = 2.571;
eps_thomsen   = 0.091;
delta_thomsen = 0.148;
gamma_thomsen = 0.105;

sigma_thomsen = alfa_thomsen^2/beta_thomsen^2*(eps_thomsen-delta_thomsen);

rho = 2.46;
Thomsen_mesaverde_sandstone = [alfa_thomsen beta_thomsen eps_thomsen delta_thomsen gamma_thomsen sigma_thomsen];

% density normalized elastic parameters
A_mesaverde_sandstone = thomsen_to_a(Thomsen_mesaverde_sandstone);

% elastic parameters
C_mesaverde_sandstone = rho*A_mesaverde_sandstone

%--------------------------------------------------------------------
% calculation of Thomsen's parameters from elastic parameters
%--------------------------------------------------------------------

Thomsen_mesaverde_sandstone_ = a_to_thomsen(A_mesaverde_sandstone);

%--------------------------------------------------------------------
% check of correctness of the formulas
%--------------------------------------------------------------------

difference = Thomsen_mesaverde_sandstone - Thomsen_mesaverde_sandstone_;


