%********************************************************************%
%                                                                    %
%  function thomsen_to_A                                             %
%                                                                    %
%  function calculates elastic parameters from Thomsen's parameters  %
%                                                                    %
%********************************************************************%
function elastic_parameters = thomsen_to_a(thomsen_parameters)

alfa_thomsen  = thomsen_parameters(1);
beta_thomsen  = thomsen_parameters(2);
eps_thomsen   = thomsen_parameters(3);
delta_thomsen = thomsen_parameters(4);
gamma_thomsen = thomsen_parameters(5);

sigma_thomsen  = alfa_thomsen^2/beta_thomsen^2*(eps_thomsen-delta_thomsen);

%--------------------------------------------------------------------
% WA parameters defined in Vavrycuk, V., 1997. Elastodynamic and 
% elastosdtatic Green tensors ..., Geophys. J. Int., 130, 786-800. 

eps(1) = alfa_thomsen^2*(delta_thomsen-2*eps_thomsen);
eps(2) = alfa_thomsen^2*(eps_thomsen-delta_thomsen);
eps(3) = beta_thomsen^2*gamma_thomsen;
alfa   = alfa_thomsen*(1+eps_thomsen);
beta   = beta_thomsen;

%--------------------------------------------------------------------
% calculation of elastic parameters

a33 = alfa_thomsen^2;
a44 = beta_thomsen^2;

a11 = a33*(1+2*eps_thomsen);
a66 = a44*(1+2*gamma_thomsen);
a13 = sqrt(2*a33.*(a33-a44).*delta_thomsen+(a33-a44).^2)-a44; % exact formula

elastic_parameters = [a11 a33 a44 a66 a13];



